@@ -1,4 +1,4 @@
-# Copyright (C)        2009 - 2010 Dirk Eddelbuettel and Romain Francois
+# Copyright (C) 2009 - 2011 Dirk Eddelbuettel and Romain Francois
 #
 # This file is part of Rcpp.
 #
@@ -20,7 +20,12 @@ Rcpp.package.skeleton <- function(
 	path = ".", force = FALSE, namespace = TRUE, 
 	code_files = character(), 
 	example_code = TRUE, 
-	module = FALSE ){
+	module = FALSE, 
+	author = "Who wrote it", 
+	maintainer = if(missing( author)) "Who to complain to" else author, 
+	email = "yourfault@somewhere.net", 
+	license = "What Licence is it under ?"
+	){
 	
 	env <- parent.frame(1)
 	
@@ -29,8 +34,10 @@ Rcpp.package.skeleton <- function(
 		assign( "Rcpp.fake.fun", function(){}, envir = env )
 		if( example_code ){
 			assign( "rcpp_hello_world", function(){}, envir = env )
+			remove_hello_world <- TRUE
+		} else {
+		    remove_hello_world <- FALSE 
 		}
-		remove_hello_world <- TRUE
 	} else {
 		if( ! "rcpp_hello_world" %in% list ){
 			call[["list"]] <- c( "rcpp_hello_world", call[["list"]] )
@@ -46,19 +53,15 @@ Rcpp.package.skeleton <- function(
 	call[[1]] <- as.name("package.skeleton")
 	call[["namespace"]] <- namespace
 	# remove Rcpp specific arguments
-	if( "example_code" %in% names( call ) ){
-		call[["example_code"]] <- NULL
-	}
-	if( "module" %in% names( call ) ){
-		call[["module"]] <- NULL
-	}
+	
+	call <- call[ c( 1L, which( names(call) %in% names(formals(package.skeleton)))) ]
 	
 	if( fake ){
 		call[["list"]] <- c( if( isTRUE(example_code)) "rcpp_hello_world" , "Rcpp.fake.fun" )
 	}
-	
+		
 	tryCatch( eval( call, envir = env ), error = function(e){
-		stop( "error while calling `package.skeleton`" )
+		stop( sprintf( "error while calling `package.skeleton` : %s", conditionMessage(e) ) )
 	} )
 	
 	message( "\nAdding Rcpp settings" )
@@ -77,6 +80,9 @@ Rcpp.package.skeleton <- function(
 			"Depends" = paste( depends, collapse = ", ") , 
 			"LinkingTo" = "Rcpp"
 		)
+		x[, "Author" ] <- author
+		x[, "Maintainer" ] <- sprintf( "%s <%s>", maintainer, email )
+		x[, "License"] <- license
 		write.dcf( x, file = DESCRIPTION )
 		message( " >> added Depends: Rcpp" )
 		message( " >> added LinkingTo: Rcpp" )
@@ -160,6 +166,12 @@ Rcpp.package.skeleton <- function(
 	
 	lines <- readLines( package.doc <- file.path( root, "man", sprintf( "%s-package.Rd", name ) ) )
 	lines <- sub( "~~ simple examples", "%% ~~ simple examples", lines )
+	
+	lines <- lines[ !grepl( "~~ package title", lines) ]
+	lines <- lines[ !grepl( "~~ The author and", lines) ]
+	lines <- sub( "Who wrote it", author, lines )
+	lines <- sub( "Who to complain to.*", sprintf( "%s <%s>", maintainer, email), lines )
+	
 	writeLines( lines, package.doc )
 	
 	if( fake ){
