@@ -2,7 +2,7 @@
 //
 // exceptions.cpp: R/C++ interface class library -- exception handling
 //
-// Copyright (C) 2009 - 2010 Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2009 - 2011 Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -51,6 +51,7 @@ RCPP_SIMPLE_EXCEPTION_WHAT(index_out_of_bounds, "index out of bounds" )
 RCPP_SIMPLE_EXCEPTION_WHAT(parse_error, "parse error") 
 RCPP_SIMPLE_EXCEPTION_WHAT(not_s4, "not an S4 object" )
 RCPP_SIMPLE_EXCEPTION_WHAT(not_reference, "not a reference S4 object" )
+RCPP_SIMPLE_EXCEPTION_WHAT(not_initialized, "C++ object not initialized" )
 RCPP_SIMPLE_EXCEPTION_WHAT(no_such_slot, "no such slot" )
 RCPP_SIMPLE_EXCEPTION_WHAT(no_such_field, "no such field" )
 RCPP_SIMPLE_EXCEPTION_WHAT(not_a_closure, "not a closure" )
@@ -120,9 +121,10 @@ void forward_uncaught_exceptions_to_r(){
     	exception_what = "unrecognized exception" ;
     }
     
+    SEXP cppExceptSym = Rf_install("cpp_exception"); 	// cannot cause a gc() once in symbol table
     Rf_eval( 
 	    Rf_lang3( 
-		     Rf_install("cpp_exception"), 
+		cppExceptSym,
 		     Rf_mkString(exception_what.c_str()), 
 		     has_exception_class ? Rf_mkString(exception_class.c_str()) : R_NilValue), 
 		R_FindNamespace(Rf_mkString("Rcpp"))
@@ -143,10 +145,11 @@ void forward_exception_to_r( const std::exception& ex){
 		} else{
 			exception_class = name ; /* just using the mangled name */
 		}
-   }
-   Rf_eval( 
+	}
+	SEXP cppExceptSym = Rf_install("cpp_exception"); // cannot cause a gc() once in symbol table
+	Rf_eval( 
 	    Rf_lang3( 
-		     Rf_install("cpp_exception"), 
+		cppExceptSym,
 		     Rf_mkString(exception_what.c_str()), 
 		     Rf_mkString(exception_class.c_str())
 		), R_FindNamespace(Rf_mkString("Rcpp"))
@@ -154,18 +157,20 @@ void forward_exception_to_r( const std::exception& ex){
 }
 #else
 void forward_uncaught_exceptions_to_r(){
+	SEXP cppExceptSym = Rf_install("cpp_exception"); // cannot cause a gc() once in symbol table
 	Rf_eval( 
 	    Rf_lang3( 
-		     Rf_install("cpp_exception"), 
+		cppExceptSym,
 		     Rf_mkString("exception : we don't know how to get the exception message with your compiler, patches welcome"), 
 		     R_NilValue), 
 		R_FindNamespace(Rf_mkString("Rcpp"))
 	     ) ; 
 }
 void forward_exception_to_r( const std::exception& ex){
+	SEXP cppExceptSym = Rf_install("cpp_exception"); // cannot cause a gc() once in symbol table
 	Rf_eval( 
 	    Rf_lang3( 
-		     Rf_install("cpp_exception"), 
+		cppExceptSym,
 		     Rf_mkString(ex.what()), 
 		     R_NilValue), 
 		R_FindNamespace(Rf_mkString("Rcpp"))
